#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-filepath
version:              0.4.14.1
visibility:           public
id:                   system-filepath-0.4.14.1-GNFzNU0ZOqO8GwdpJXBxeC
key:                  system-filepath-0.4.14.1-GNFzNU0ZOqO8GwdpJXBxeC
license:              MIT
copyright:            John Millikin 2010-2012
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    High-level, byte-based file and directory path manipulations (deprecated)

description:
    High-level, byte-based file and directory path manipulations (deprecated).

category:             System
abi:                  e9f2dd73c7eb6fc2c1b80773aaf7fd69
exposed:              True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules

hidden-modules:       Filesystem.Path.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-filepath
hs-libraries:         HSsystem-filepath-0.4.14.1-GNFzNU0ZOqO8GwdpJXBxeC
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock

haddock-html:         /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

